@@ -16,7 +16,6 @@ from mistral.db.v2 import api as db_api
 from mistral import exceptions as exc
 from mistral.lang import parser as spec_parser
 from mistral import utils
-from mistral.workflow import data_flow
 from mistral.workflow import states
 from oslo_log import log as logging
 
@@ -136,8 +135,6 @@ def update_workflow_execution_env(wf_ex, env):
 
     wf_ex.params['env'] = utils.merge_dicts(wf_ex.params['env'], env)
 
-    data_flow.add_environment_to_context(wf_ex)
-
     return wf_ex
 
 
