@@ -17,12 +17,12 @@ from eventlet import semaphore
 from oslo_config import cfg
 import testtools
 
-from mistral.actions import base as action_base
 from mistral.db.v2 import api as db_api
 from mistral.services import workflows as wf_service
 from mistral.tests.unit import base as test_base
 from mistral.tests.unit.engine import base
 from mistral.workflow import states
+from mistral_lib import actions as actions_base
 
 
 # Use the set_default method to set value otherwise in certain test cases
@@ -88,7 +88,7 @@ ACTION_SEMAPHORE = None
 TEST_SEMAPHORE = None
 
 
-class BlockingAction(action_base.Action):
+class BlockingAction(actions_base.Action):
     def __init__(self):
         pass
 
@@ -100,7 +100,7 @@ class BlockingAction(action_base.Action):
     def wait_for_test():
         ACTION_SEMAPHORE.acquire()
 
-    def run(self):
+    def run(self, context):
         self.unblock_test()
         self.wait_for_test()
 
@@ -141,29 +141,38 @@ class EngineActionRaceConditionTest(base.EngineTestCase):
 
         self.block_action()
 
-        wf_ex = self.engine.start_workflow('wf', None)
+        wf_ex = self.engine.start_workflow('wf', '', None)
 
-        wf_ex = db_api.get_workflow_execution(wf_ex.id)
+        with db_api.transaction():
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
+
+            task_execs = wf_ex.task_executions
 
         self.assertEqual(states.RUNNING, wf_ex.state)
-        self.assertEqual(states.RUNNING, wf_ex.task_executions[0].state)
+        self.assertEqual(states.RUNNING, task_execs[0].state)
 
         self.wait_for_action()
 
-        # Here's the point when the action is blocked but already running.
-        # Do the same check again, it should always pass.
-        wf_ex = db_api.get_workflow_execution(wf_ex.id)
+        with db_api.transaction():
+            # Here's the point when the action is blocked but already running.
+            # Do the same check again, it should always pass.
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
+
+            task_execs = wf_ex.task_executions
 
         self.assertEqual(states.RUNNING, wf_ex.state)
-        self.assertEqual(states.RUNNING, wf_ex.task_executions[0].state)
+        self.assertEqual(states.RUNNING, task_execs[0].state)
 
         self.unblock_action()
 
         self.await_workflow_success(wf_ex.id)
 
-        wf_ex = db_api.get_workflow_execution(wf_ex.id)
+        with db_api.transaction():
+            wf_ex = db_api.get_workflow_execution(wf_ex.id)
 
-        self.assertDictEqual({'result': 'test'}, wf_ex.output)
+            wf_output = wf_ex.output
+
+        self.assertDictEqual({'result': 'test'}, wf_output)
 
     # TODO(rakhmerov): Should periodically fail now because of poor
     # transaction isolation support in SQLite. Requires more research
@@ -174,7 +183,7 @@ class EngineActionRaceConditionTest(base.EngineTestCase):
 
         self.block_action()
 
-        wf_ex = self.engine.start_workflow('wf', None)
+        wf_ex = self.engine.start_workflow('wf', '', None)
 
         wf_ex = db_api.get_workflow_execution(wf_ex.id)
 
